#[repr(u8)]pub enum Swbk {
NO_SWING = 0,
SWING_BACK = 1,
}Variants
NO_SWING = 0
No swing back cycle has completed since the last time the flag was cleared
SWING_BACK = 1
At least one swing back cycle has occurred since the last time the flag was cleared
Implementations